@@ -5,7 +5,7 @@ seed <- 1
 source(paste0("", "testUtils.R"))
 
 test_that(getTestName("Simulate a 1-cpt model without OMEGA's/SIGMA's - Github issue #8"), {
-  model <- model_library$advan2_trans2
+  model <- model_suite$nonmem$advan2_trans2
 
   # Keep THETA's only
   model@parameters <- model@parameters %>% select("theta")
@@ -28,4 +28,4 @@ test_that(getTestName("Simulate a 1-cpt model without OMEGA's/SIGMA's - Github i
     expect_equal(subject2, subject3)
   )
   campsisTest(simulation, test, env=environment())
-})
\ No newline at end of file
+})
