@@ -7,9 +7,9 @@ seed <- 1
 source(paste0("", "testUtils.R"))
 
 test_that(getTestName("Test generated RUV is correct"), {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   
-  ds <- Dataset(100) %>%
+  ds <- Dataset(500) %>%
     add(Bolus(0, 1000)) %>%
     add(Observations(times=seq(0.1,24,by=0.1))) # No predose to avoid zero's
   
@@ -23,4 +23,4 @@ test_that(getTestName("Test generated RUV is correct"), {
     expect_equal(round(var(eps), 3), 0.025)
   )
   campsisTest(simulation, test, env=environment())
-})
\ No newline at end of file
+})
